@@ -1,5 +1,7 @@
 use crate::profile::Profile;
+use crate::EntityError;
 use ockam_core::hex::encode;
+use ockam_core::Result;
 use ockam_vault_core::{Hasher, KeyId};
 use serde::{Deserialize, Serialize};
 
@@ -17,6 +19,13 @@ impl ProfileIdentifier {
     pub fn to_external(&self) -> String {
         format!("P_ID.{}", &self.0)
     }
+    pub fn from_external(str: &str) -> Result<Self> {
+        if let Some(str) = str.strip_prefix("P_ID.") {
+            Ok(Self::from(str))
+        } else {
+            Err(EntityError::InvalidProfileId.into())
+        }
+    }
 
     /// Return the wrapped KeyId
     pub fn key_id(&self) -> &KeyId {
