@@ -1,14 +1,13 @@
 use crate::{
     CredentialHolder, CredentialIssuer, CredentialProof, CredentialPublicKey,
-    CredentialRequestFragment, CredentialVerifier, EntityError::IdentityApiFailed, Identity,
-    IdentityRequest, IdentityRequest::*, IdentityResponse as Res, MaybeContact, NoOpTrustPolicy,
-    ProfileIdentifier, ProfileState, SecureChannelTrait,
+    CredentialRequestFragment, CredentialVerifier, EntityError::IdentityApiFailed, Handle,
+    Identity, IdentityRequest, IdentityRequest::*, IdentityResponse as Res, MaybeContact,
+    NoOpTrustPolicy, Profile, ProfileIdentifier, ProfileState, SecureChannelTrait,
 };
-
 use async_trait::async_trait;
 use ockam_core::{
     lib::{result::Result::Ok, HashMap},
-    Result, Routed, Worker,
+    Address, Result, Routed, Worker,
 };
 use ockam_node::Context;
 use ockam_vault_sync_core::{Vault, VaultSync};
@@ -69,17 +68,31 @@ impl Worker for EntityWorker {
             RotateKey(profile_id) => {
                 let profile = self.profile(&profile_id);
 
-                Identity::rotate_key(profile)
+                Identity::rotate_profile_key(profile)
             }
-            GetPublicKey(profile_id) => {
-                if let Ok(public_key) = self.profile(&profile_id).get_public_key() {
+            GetProfilePublicKey(profile_id) => {
+                if let Ok(public_key) = self.profile(&profile_id).get_profile_public_key() {
+                    ctx.send(reply, Res::GetProfilePublicKey(public_key)).await
+                } else {
+                    err()
+                }
+            }
+            GetProfileSecretKey(profile_id) => {
+                if let Ok(secret) = self.profile(&profile_id).get_profile_secret_key() {
+                    ctx.send(reply, Res::GetProfileSecretKey(secret)).await
+                } else {
+                    err()
+                }
+            }
+            GetPublicKey(profile_id, label) => {
+                if let Ok(public_key) = self.profile(&profile_id).get_public_key(label) {
                     ctx.send(reply, Res::GetPublicKey(public_key)).await
                 } else {
                     err()
                 }
             }
-            GetSecretKey(profile_id) => {
-                if let Ok(secret) = self.profile(&profile_id).get_secret_key() {
+            GetSecretKey(profile_id, label) => {
+                if let Ok(secret) = self.profile(&profile_id).get_secret_key(label) {
                     ctx.send(reply, Res::GetSecretKey(secret)).await
                 } else {
                     err()
@@ -146,30 +159,44 @@ impl Worker for EntityWorker {
                     None => MaybeContact::None,
                     Some(contact) => MaybeContact::Contact(contact),
                 };
-                ctx.send(reply, message).await
+                ctx.send(reply, Res::GetContact(message)).await
             }
             CreateSecureChannelListener(profile_id, address) => {
-                let profile = self.profile(&profile_id);
+                let vault_address = self.profile(&profile_id).vault().address();
+                let handle = Handle::new(ctx.new_context(Address::random(0)).await?, ctx.address());
+                let profile = Profile::new(profile_id, handle);
                 SecureChannelTrait::create_secure_channel_listener_async(
                     profile,
                     &ctx,
                     address,
                     NoOpTrustPolicy, // TODO wire up some serializable policy descriptor
-                    &profile.vault().address(),
-                )
-                .await
-            }
-            CreateSecureChannel(profile_id, route) => {
-                let profile = self.profile(&profile_id);
-                let address = SecureChannelTrait::create_secure_channel_async(
-                    profile,
-                    &ctx,
-                    route,
-                    NoOpTrustPolicy, // TODO policy
-                    &profile.vault().address(),
+                    &vault_address,
                 )
                 .await?;
-                ctx.send(reply, Res::CreateSecureChannel(address)).await
+                ctx.send(reply, Res::CreateSecureChannelListener).await
+            }
+            CreateSecureChannel(profile_id, route) => {
+                let vault_address = self.profile(&profile_id).vault().address();
+                let handle = Handle::new(ctx.new_context(Address::random(0)).await?, ctx.address());
+                let profile = Profile::new(profile_id.clone(), handle);
+
+                let child_ctx = ctx.new_context(Address::random(0)).await?;
+                let rt = ctx.runtime();
+                rt.spawn(async move {
+                    let address = SecureChannelTrait::create_secure_channel_async(
+                        profile,
+                        &child_ctx,
+                        route,
+                        NoOpTrustPolicy, // TODO policy
+                        &vault_address,
+                    )
+                    .await?;
+                    child_ctx
+                        .send(reply, Res::CreateSecureChannel(address))
+                        .await
+                });
+
+                Ok(())
             }
             GetSigningKey(profile_id) => {
                 if let Ok(signing_key) = self.profile(&profile_id).get_signing_key() {
@@ -179,7 +206,7 @@ impl Worker for EntityWorker {
                 }
             }
             GetIssuerPublicKey(profile_id) => {
-                if let Ok(public_key) = self.profile(&profile_id).get_issuer_public_key() {
+                if let Ok(public_key) = self.profile(&profile_id).get_signing_public_key() {
                     ctx.send(
                         reply,
                         Res::GetIssuerPublicKey(CredentialPublicKey(public_key)),
